OC.L10N.register(
    "files_external",
    {
    "External storage" : "Almacenamiento externo",
    "Personal" : "Personal",
    "Grant access" : "Permitir acceso",
    "Saved" : "Guardado",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Save" : "Guardar",
    "API key" : "clave API",
    "Port" : "Puerto",
    "Region" : "Provincia",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Location" : "Ubicación",
    "ownCloud" : "ownCloud",
    "Host" : "Servidor",
    "Share" : "Compartir",
    "Name" : "Nombre",
    "External Storage" : "Almacenamiento externo",
    "Folder name" : "Nombre de la carpeta",
    "Configuration" : "Configuración",
    "Add storage" : "Añadir almacenamiento",
    "Delete" : "Borrar"
},
"nplurals=2; plural=(n != 1);");
